==> 1.10.0.zip: Docxtor.app/Contents/Frameworks/Sparkle.framework/Versions/A/PrivateHeaders/._SUUnarchiver.h <==
    Mac OS X            	   2  )~     )                                      ATTR      )  L  (d                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements      x     com.apple.cs.CodeRequirements-1      #,  com.apple.cs.CodeSignature                 4                     ASUUnarchiver P3W489K935 L7\PdqgH                                        <:>+BRnUF߰>                    dt'e3+]fuqq  <?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
	<dict>
		<key>com.apple.security.app-sandbox</key>
		<true/>
		<key>com.apple.security.automation.apple-events</key>
		<true/>
		<key>com.apple.security.network.client</key>
		<true/>
		<key>com.apple.security.files.user-selected.read-write</key>
		<true/>
		<key>com.apple.security.temporary-exception.apple-events</key>
		<array>
			<string>com.apple.iWork</string>
			<string>com.apple.iWork.Pages</string>
			<string>com.apple.iWork.Numbers</string>
			<string>com.apple.iWork.Keynote</string>
		</array>
	</dict>
</plist>
                            SUUnarchiver                  
*Hcd                   
*Hcd
                
subject.OU        
P3W489K935               4                      ASUUnarchiver P3W489K935 ~9VOqqqPKF                                                                Gzw,x
ޗȄJğke3Iy                                I jt%"Z>m
A`CMvjR=>>0	*H
010
	`He 0	*H
  ;00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!0p0X*u4=0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
180215074532Z
230216074532Z010
	&,d
P3W489K9351;09U2Developer ID Application: Martin Kolb (P3W489K935)10U
P3W489K93510U
Martin Kolb10	UUS0"0
	*H
  0
 ZD͆FB+1iS#L2#Lӭgqw=b^rsSB (֫=Mn4jRcm(v4Եã!ǈWl8,ZIJ'Ӭt(Ma=sR$>_ζcf,fBTIK
2M<0Tc\_`KE$e
Ш 5=51@g\ @iq:, hFl]3(uxikӮ"	 00>+2000.+0"http://ocsp.apple.com/ocsp-devid010Ud|I*iieE0U0 0U#0W|-,T0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U0U%0
+0
*Hcd
 0
	*H
  =sy]ԅVytBCkJy|x$ɼk&_;\kTZ9-2*_TF	%XBvADSc&,}FEP
Ftw4.u!+Qc?B-HfP46<8L,r#UЄ@^
v2}/o3eʒªSJl,#i8Vj:[l1000y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS*u4=0
	`He %0	*H
	1	*H
0	*H
	1
190607104051Z0/	*H
	1" SLmyu##̷"D=-1x0[	*Hcd	1N0-	`He kŘqB]?	@Hhܟٓ0+d S%'ltFA0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		j2QArlPBJcEn85dsuXRGpEG/s7M=
		</data>
		<data>
		a5zDxZjLcRni8p9CXT/pCZFASMs=
		</data>
	</array>
</dict>
</plist>
0
	*H
  '{V׾a)dvaZvp\oD6O&d,Ry8vsQi!T,Ȧt"wxX{=i`~=m9qTmh!L0Y7h,*hOpQ}NUf#q(l{Uei IaG2ѩ%aTP}Fje	|Wetw2v+EreΡ0*H
	10	*H
010	+ 0{*H
	lj0h*010
	`He  X.Cf9zhzhJH޽"8nVY/'S |-ͦ20190607104051Z0	 ո+W
00ucsfQ0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
190603211002Z
190715211002Z0B10UTimestamp Signer RNO210U

Apple Inc.10	UUS0"0
	*H
  0
 My񔇄Uطҳg)x^~r6*)$ަ7N&C!hs鳂ڬoXU0sFU"D9LYfܬQج3x> 0
}N͸g;H
N&JdڌAl<˴8!a{BB ֱEvag`BHw*} #+p)nNOR5;E~q%Xo;boڛ=v*AgNL 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Ug^~â{S΁0U0
	*H
  bz8ֈ=͌֓nx?"7(Vx/l1$mK?V:ExĂ1u7r[?:/N,_! +?VrcD,S	*	mQD:ʐpXS5ߖ%(<V	թJk!&ώ<Δ$.7|(0=	Č+qlO`;(f>-KSi_խ=J RnS{S(yD00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSucsfQ0	+ 0	*H
	1
*H
	0	*H
	1
190607104051Z0#	*H
	1mѣ>Y-Sb#s0+*H
	1000{7u4jo
-h0
	*H
  4G˽`rIh'ܫ;RoNwq=(wKp%=
]Re:Ms2dRy+Ct#v$Tw_3 b<7&fbg7p'~Qmi,!KuT-K
`wvp46ļd'	/R1߰`:`0C||gO@su" W?'J8o\$      

==> 1.12.0.zip: Docxtor.app/Contents/Frameworks/Sparkle.framework/Versions/A/PrivateHeaders/._SUUnarchiver.h <==
    Mac OS X            	   2  )}     )                                      ATTR      )  L  (c                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements      x     com.apple.cs.CodeRequirements-1      #+  com.apple.cs.CodeSignature                 4                     ASUUnarchiver P3W489K935 L7\PdqgH                                        <:>+BRnUF߰>                    dt'e3+]fuqq  <?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
	<dict>
		<key>com.apple.security.app-sandbox</key>
		<true/>
		<key>com.apple.security.automation.apple-events</key>
		<true/>
		<key>com.apple.security.network.client</key>
		<true/>
		<key>com.apple.security.files.user-selected.read-write</key>
		<true/>
		<key>com.apple.security.temporary-exception.apple-events</key>
		<array>
			<string>com.apple.iWork</string>
			<string>com.apple.iWork.Pages</string>
			<string>com.apple.iWork.Numbers</string>
			<string>com.apple.iWork.Keynote</string>
		</array>
	</dict>
</plist>
                            SUUnarchiver                  
*Hcd                   
*Hcd
                
subject.OU        
P3W489K935               4                      ASUUnarchiver P3W489K935 ~9VOqqqPKF                                                                Gzw,x
ޗȄJğke3Iy                                I jt%"Z>m
A`CMvjR=>>0	*H
010
	`He 0	*H
  ;00z!0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120201221215Z
270201221215Z0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 vO[A#+_s?5
?$?O>mG	V)甝5
ʹ`)xEii`k_#:"1O4YBx.3E
EoZ[:2m6lp&D{HX#ş9~]2_R@꾬d[jDl>İ&{^j=GX1? v(mNi&NVtKfxLY 00UW|-,T0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd 0
	*H
  B9tkƤ7*
D,Ya2Կ;P9jDt[pKl#q-_œpe-xXI(3 zvOߨJVg/>ă:wmt.#Qo`H»ZFE~' "rorPu=%] 6H9;ꐀ.`x
S>O2VMxଚBzFXV,*EK4aUD'sNp000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!0p0X*u4=0
	*H
 0y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
180215074532Z
230216074532Z010
	&,d
P3W489K9351;09U2Developer ID Application: Martin Kolb (P3W489K935)10U
P3W489K93510U
Martin Kolb10	UUS0"0
	*H
  0
 ZD͆FB+1iS#L2#Lӭgqw=b^rsSB (֫=Mn4jRcm(v4Եã!ǈWl8,ZIJ'Ӭt(Ma=sR$>_ζcf,fBTIK
2M<0Tc\_`KE$e
Ш 5=51@g\ @iq:, hFl]3(uxikӮ"	 00>+2000.+0"http://ocsp.apple.com/ocsp-devid010Ud|I*iieE0U0 0U#0W|-,T0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U0U%0
+0
*Hcd
 0
	*H
  =sy]ԅVytBCkJy|x$ɼk&_;\kTZ9-2*_TF	%XBvADSc&,}FEP
Ftw4.u!+Qc?B-HfP46<8L,r#UЄ@^
v2}/o3eʒªSJl,#i8Vj:[l1000y1-0+U$Developer ID Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS*u4=0
	`He %0	*H
	1	*H
0	*H
	1
200501135407Z0/	*H
	1" SLmyu##̷"D=-1x0[	*Hcd	1N0+d S%'ltFA0-	`He kŘqB]?	@Hhܟٓ0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
<plist version="1.0">
<dict>
	<key>cdhashes</key>
	<array>
		<data>
		j2QArlPBJcEn85dsuXRGpEG/s7M=
		</data>
		<data>
		a5zDxZjLcRni8p9CXT/pCZFASMs=
		</data>
	</array>
</dict>
</plist>
0
	*H
  _G%ʤO!{lJC;Ҍ p%|U(GT>;+ⱓo&F,XFtTtdK)(ο6*LLOȬK1+4io
wm$v?=@x޻g$&qsEy~Oҭ,2L絣GM^( '(8l*O'FV5IsKQ"XAoɐjR*0*H
	10	*H
010	+ 0{*H
	lj0h*010
	`He  ;'{>##:cEB.cp<>9z20200501135407Z0	 ܺ
00Q̴H0
	*H
 0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0
200429221002Z
200610221002Z0A10UTimestamp Signer MA110U

Apple Inc.10	UUS0"0
	*H
  0
 եnKS8Á(@WG_^6B(G 
9ᵠ8=J]_HܓQ_ͽ1qnmeXXPU4͆^a~1i}f,0lKP1@/[,iF/A/%")oS	~[_ϕyM%\6*v{z1s=
+=7qcf#
y,|equ4n1= Y1i 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uevq+	V6\Hp60U0
	*H
  C 6ҜҲs'Ȭ2`sUNPيv|
=x(IsxSSi.sQ!d.hΊ%gyD7hE#Tln;o"6?	DU^~yQA_>8.2>C.~E2bn3o,1X}(D@SoxTa7r4mX"	o^h6X
cY_zqh;as00}LWc0
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
120405120244Z
270405120244Z0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUS0"0
	*H
  0
 wg\.#g>B	}
s@/P'4p
<No97ڞecIm] 9	:JidF5ea.
=o%L	x"!{[ѣ~I;
r3,JZr
9Pt(ny_~VVlĮ (tM&By^`EXQI^JMs{Rˣ]klt-D>a>E~4u&@u0Kw 00U4%N78X&)0U00U#0+iGv	k.@GM^0.U'0%0#!http://crl.apple.com/root.crl0U0
*Hcd	 0
	*H
  6qS#xe[#Ǣϴ(p!93rC=BQu]ˌjj:T}k>mzT_Cv\ N<>r4\ge0B4ӧBsu|QC`ܮ'kg3EoɘMiKEN"W""En?厸F\ɰ:m7(FeoUhR>?&:k22H;Kу000
	*H
 0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0
060425214036Z
350209214036Z0b10	UUS10U

Apple Inc.1&0$UApple Certification Authority10U
Apple Root CA0"0
	*H
  0
 䑩	GP^y-6WLUKl"0>P	Af$kУ*zG[73Mir]_%UM]
d5#KYPXPg ˬ, op?0C=+I(ε^=: !.t<
bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U00U+iGv	k.@GM^0U#0+iGv	k.@GM^0U 00 	*Hcd00*+https://www.apple.com/appleca/0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0
	*H
  \6L-x팛wvw0O=G7@,ԱؾsdyO4آ>xk}9S 8ıO
k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
/Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U

Apple Inc.10	UUSQ̴H0	+ 0	*H
	1
*H
	0	*H
	1
200501135407Z0#	*H
	1̶tVn͓00+*H
	1000l ?ꌴ*?3Uy=0
	*H
  8"5W\=}׫2c`0nԐ*Q;Tqp7oYU+6ۃ0AfSY,^^&6A
Q
ඐWcJibXw<PiW1 ^<tzyXmcbafPfqYX	Ml@(j';ܝ۶\za2>	Pg~!EW<<>V|VKuh^TlVCWݮBMDyrN?OȌ8[;b      
